==> epiphany-2.21.4.tar.gz: epiphany-2.21.4/embed/xulrunner/src/gecko-embed-marshal.h <==

#ifndef __gecko_embed_marshal_MARSHAL_H__
#define __gecko_embed_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOXED (../../../../embed/xulrunner/src/gecko-embed-marshal.list:1) */
extern void gecko_embed_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* BOOLEAN:POINTER (../../../../embed/xulrunner/src/gecko-embed-marshal.list:2) */
extern void gecko_embed_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* BOOLEAN:STRING (../../../../embed/xulrunner/src/gecko-embed-marshal.list:3) */
extern void gecko_embed_marshal_BOOLEAN__STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:INT,INT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:4) */
extern void gecko_embed_marshal_VOID__INT_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:INT,UINT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:5) */
extern void gecko_embed_marshal_VOID__INT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:OBJECT,UINT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:6) */
extern void gecko_embed_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:POINTER,INT,POINTER (../../../../embed/xulrunner/src/gecko-embed-marshal.list:7) */
extern void gecko_embed_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:POINTER,UINT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:8) */
extern void gecko_embed_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:STRING,INT,INT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:9) */
extern void gecko_embed_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:STRING,INT,UINT (../../../../embed/xulrunner/src/gecko-embed-marshal.list:10) */
extern void gecko_embed_marshal_VOID__STRING_INT_UINT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

G_END_DECLS

#endif /* __gecko_embed_marshal_MARSHAL_H__ */

==> epiphany-2.21.5.tar.gz: epiphany-2.21.5/embed/xulrunner/src/gecko-embed-marshal.h <==

#ifndef __gecko_embed_marshal_MARSHAL_H__
#define __gecko_embed_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOXED (gecko-embed-marshal.list:1) */
extern void gecko_embed_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* BOOLEAN:POINTER (gecko-embed-marshal.list:2) */
extern void gecko_embed_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* BOOLEAN:STRING (gecko-embed-marshal.list:3) */
extern void gecko_embed_marshal_BOOLEAN__STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:INT,INT (gecko-embed-marshal.list:4) */
extern void gecko_embed_marshal_VOID__INT_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:INT,UINT (gecko-embed-marshal.list:5) */
extern void gecko_embed_marshal_VOID__INT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:OBJECT,UINT (gecko-embed-marshal.list:6) */
extern void gecko_embed_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:POINTER,INT,POINTER (gecko-embed-marshal.list:7) */
extern void gecko_embed_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:POINTER,UINT (gecko-embed-marshal.list:8) */
extern void gecko_embed_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:STRING,INT,INT (gecko-embed-marshal.list:9) */
extern void gecko_embed_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:STRING,INT,UINT (gecko-embed-marshal.list:10) */
extern void gecko_embed_marshal_VOID__STRING_INT_UINT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

G_END_DECLS

#endif /* __gecko_embed_marshal_MARSHAL_H__ */
